︠e5c47641-be08-4293-a854-95833871af15i︠
%md
## Computing the conductor of Picard curves ##

### 1. Example ###
We consider the Picard curve
$$
     Y:\; y^3 = f(x) = x^4 + 14x^2 + 72x -41.
$$
The discriminant of $f$ is $\Delta(f)=-2^{10}3^45^6$.

Our goal is to compute the conductor $N_Y = 2^{f_2}3^{f_3}5^{f_5}$.
︡580e9ef4-f5c8-4f2f-aca3-2e86b98573c9︡{"done":true,"md":"## Computing the conductor of Picard curves ##\n\n### 1. Example ###\nWe consider the Picard curve\n$$\n     Y:\\; y^3 = f(x) = x^4 + 14x^2 + 72x -41.\n$$\nThe discriminant of $f$ is $\\Delta(f)=-2^{10}3^45^6$.\n\nOur goal is to compute the conductor $N_Y = 2^{f_2}3^{f_3}5^{f_5}$."}
︠73e127eb-5807-4b60-a0f8-04204d1fccc0s︠
K = QQ
R.<x> = K[]
f = x^4 +14*x^2 + 72*x -41
f.discriminant().factor()
︡fd18a604-592c-4707-92d2-af2134cc9577︡{"stdout":"-1 * 2^10 * 3^4 * 5^6\n"}︡{"done":true}︡
︠e995d0bc-747d-40b1-9213-99ad65d352dbi︠
%md
We check that $p=5$ is an exceptional prime. It follows that $f_5=0$. (Note that $v_5(\Delta(f))=6$.)
︡218d15ce-e2e3-48ce-83b7-e1fb26cef5cc︡{"done":true,"md":"We check that $p=5$ is an exceptional prime. It follows that $f_5=0$. (Note that $v_5(\\Delta(f))=6$.)"}
︠f1545abc-12de-4cdc-8447-d9dff433832bs︠
f.change_ring(GF(5)).factor()
(f(-58+5^3*x)/5^6).change_ring(GF(5))
︡c030fbaf-f957-4840-9312-4bb402ae0cfa︡{"stdout":"(x + 3)^2 * (x^2 + 4*x + 1)"}︡{"stdout":"\n"}︡{"stdout":"3*x^2 + 4*x + 2\n"}︡{"done":true}︡
︠be654a5f-b7d3-4ced-9ba2-70bead5187d3s︠
vK = pAdicValuation(K, 5)
vK.mac_lane_approximants(f)
︡b12aa3e0-c6ad-4852-be41-b153e7a178bd︡{"stdout":"[[ Gauss valuation induced by 5-adic valuation, v(x + 58) = 3, v(x^2 + 491*x + 87614) = 7 ], [ Gauss valuation induced by 5-adic valuation, v(x^2 + 134*x + 356) = 4 ]]"}︡{"stdout":"\n"}︡{"done":true}︡
︠ae8bd21e-e036-4c81-941c-fc2842527a72i︠
%md
Now we want to compute $f_2$. 

First we compute the splitting field of $f$. It is a totally ramified extension of $\QQ$ of degree $8$. The configuration of the roots of $f$ is as follows: they all lie in a disk of radius $3/4$, and inside in two smaller disks of radius $1$.
︡def57773-6419-4728-bd0e-e9be1472a5cd︡{"done":true,"md":"Now we want to compute $f_2$. \n\nFirst we compute the splitting field of $f$. It is a totally ramified extension of $\\QQ$ of degree $8$. The configuration of the roots of $f$ is as follows: they all lie in a disk of radius $3/4$, and inside in two smaller disks of radius $1$."}
︠35729126-efab-4035-993f-301f459bae3ds︠
f.change_ring(GF(2)).factor()
vK = pAdicValuation(K, 2)
vK.montes_factorization(f)      # shows that f is irreducible over QQ_2
L0.<alpha0> = K.extension(f)
L0.<alpha>= L0.galois_closure()
L0
vL0 = vK.extension(L0)
vL0(2)
fL0 = f.change_ring(L0)
a = fL0.roots(multiplicities=None)
[vL0(a[0]-a[i]) for i in range(4)]
︡d253ea57-eaa8-44af-8af5-9f077b93fe22︡{"stdout":"(x + 1)^4\n"}︡{"stdout":"x^4 + 14*x^2 + 72*x - 41\n"}︡{"stdout":"Number Field in alpha with defining polynomial x^8 + 40*x^6 + 2400*x^4 + 81472*x^2 + 1000000\n"}︡{"stdout":"8\n"}︡{"stdout":"[+Infinity, 6, 6, 8]\n"}︡{"done":true}︡
︠c4f7933c-b648-4cde-9f16-0d7306f8f9f8i︠
%md
We compute the MacLane valuations $v_1,v_2$ on $K[x]$ corresponding to the configuration of roots.
︡650dde97-eb00-4580-a402-a98ae1f4b67e︡{"done":true,"md":"We compute the MacLane valuations $v_1,v_2$ on $K[x]$ corresponding to the configuration of roots."}
︠1fbe599b-394f-4007-825b-d8a5c7de32adi︠

︡6ee15409-9eae-4dbd-b2e7-277e03ba8c19︡
︠16096501-0dab-4e80-ad71-d68c178c2cbb︠

︡a59a560b-8a9d-40b0-84b2-d88286696421︡
︠1f3d8b8d-c542-4a89-9542-04987379f903s︠
v0 = GaussValuation(R, vK)
v = v0.mac_lane_step(f)[0]
v1 = v.extension(f, 3)
v1
v2 = v.extension(f, 7/2)
v2
︡de2aa3d2-b32c-4b7f-b0a1-8066ca3984fc︡{"stdout":"[ Gauss valuation induced by 2-adic valuation, v(x + 1) = 1/4, v(x^4 + 14*x^2 + 72*x - 41) = 3 ]\n"}︡{"stdout":"[ Gauss valuation induced by 2-adic valuation, v(x + 1) = 1/4, v(x^4 + 14*x^2 + 72*x - 41) = 7/2 ]\n"}︡{"done":true}︡
︠e6e00de9-68ea-4e95-bf11-7e236cf9ec6ei︠
%md 
From the configuration of roots of $f$ it is clear that the stable reduction of $Y$ has three components of genus $1$ (Case (c) in Theorem 4.1).
The extension $L/K$ over which $Y$ aquires semistable reduction is a (tamely ramified) extension of $L_0$ of degree $3$.

︡cd4a2e4d-1e2a-4dde-898c-b663eb7c2cc1︡{"done":true,"md":"From the configuration of roots of $f$ it is clear that the stable reduction of $Y$ has three components of genus $1$ (Case (c) in Theorem 4.1).\nThe extension $L/K$ over which $Y$ aquires semistable reduction is a (tamely ramified) extension of $L_0$ of degree $3$."}
︠7ec27860-0b0f-40c2-a20d-6e1dcf4e40b8s︠
v0 = GaussValuation(fL0.parent(), vL0)
v0(f((x-a[0])/(a[1]-a[0])))
v0(f((x-a[0])/(a[3]-a[0])))   # since this is not divisible by 3, we need L/L_0 to be ramified
︡c99b79e9-e518-480c-afdf-dd5d53548335︡{"stdout":"-24\n"}︡{"stdout":"-32\n"}︡{"done":true}︡
︠8b30b447-3dbe-465e-8b8d-90d3ec9316f0︠
︡0079aa1a-6b59-485f-a22d-ed0be8df09a4︡
︠a4298547-4a55-4662-ad4a-aeac44b381e6i︠
%md
We compute the jumps in the filtration of higher ramification groups of the extension $L$. It turns out that these are $0,3,9,15$. Here $\Gamma_3$ is a dihedral group of order $8$, $\Gamma_9$ is of order $4$, and $\Gamma_{15}$ is the center (of order $2$).

We also compute the subfields of $L$ corresponding to the jumps.
︡1ad2d83e-d92d-40a2-aa37-5b7f9d46ff50︡{"done":true,"md":"We compute the jumps in the filtration of higher ramification groups of the extension $L$. It turns out that these are $0,3,9,15$. Here $\\Gamma_3$ is a dihedral group of order $8$, $\\Gamma_9$ is of order $4$, and $\\Gamma_{15}$ is the center (of order $2$).\n\nWe also compute the subfields of $L$ corresponding to the jumps."}
︠5abab4a0-b5ba-412b-90a5-fb230e2e0b0bs︠
load("../../padic_extensions/padic_extensions.sage")
vL0 = padic_splitting_field(vK, f)
L0 = vL0.domain()
L0
P = L0.polynomial()
P = P(P.parent().gen()^3)
P
︡b999d8d9-15ee-418b-bf03-bc41b6180dec︡{"stdout":"Number Field in pi8 with defining polynomial x^8 + 20*x^7 + 8*x^6 + 72*x^5 + 70*x^4 + 48*x^3 + 76*x^2 + 16*x + 82\n"}︡{"stdout":"x^24 + 20*x^21 + 8*x^18 + 72*x^15 + 70*x^12 + 48*x^9 + 76*x^6 + 16*x^3 + 82\n"}︡{"done":true}︡
︠33821a19-8d9e-4a59-8c0e-a3db11b5e421s︠
load("../../padic_extensions/padic_extensions.sage")
L.<pi> = K.extension(P)
vL = vK.extension(L)
filt = padic_ramification_filtration(vL, compute_subfields=True)
filt
︡53ad0b2c-11d2-42d3-9ab6-687cce11d1bd︡{"stdout":"[(15, 2, pi12-adic valuation), (9, 4, pi6-adic valuation), (3, 8, pi3-adic valuation), (0, 24, 2-adic valuation)]\n"}︡{"done":true}︡
︠f0fc097f-162d-4683-baca-4bdad0eeef55︠
︡e4736d41-092d-470a-a87c-2290a81515ea︡
︠69a8be7f-b706-42e2-a855-3607f9e01609i︠
%md
For $m=0,\ldots,15$, we have to compute the genus of the curve $\bar{Y}_m:=\bar{Y}/\Gamma_m$. We do this by extending the valuations $v_1,v_2$ from $K(x)$ to the function field $L_m(Y)=L_m(x,y)$ and computing the genera of the residue fields of these extensions.  
︡598e7da3-7eb0-459f-81a2-5549d3ea43bb︡{"done":true,"md":"For $m=0,\\ldots,15$, we have to compute the genus of the curve $\\bar{Y}_m:=\\bar{Y}/\\Gamma_m$. We do this by extending the valuations $v_1,v_2$ from $K(x)$ to the function field $L_m(Y)=L_m(x,y)$ and computing the genera of the residue fields of these extensions."}
︠a994611b-312e-4a65-ab22-a26c4c20f2e1︠
︡24308a41-f396-48e3-b475-1cad21b8fa44︡
︠c8ceef4b-d623-4e9d-9aa9-1f92f4aae9a9︠
︡8ee59f1c-aabe-4d9a-8ca2-6fcd56ebbf38︡
︠181fc54d-6935-415e-b316-59cbe1aff16e︠

︡20ab5c9b-c853-4e8f-8fdb-34ab47e6367a︡
︠653e42f0-923e-4a9a-be94-bfe373f546fbs︠
load("../../MacLane_valuations/maclane.sage")
def reduction_component(v, vLm, f):
    
    p = vLm.residue_field().characteristic()
    Lm = vLm.domain()
    FXL.<z> = FunctionField(Lm)
    h = FXL._ring(v.phi())
    V = maclane_basefield_extensions(v, vLm, h)
    S.<T> = FXL[]
    FYL.<y> = FXL.extension(T^3-FXL(f))
    for w in V:
        w = RationalFunctionFieldValuation(FXL, w)
        w = w.extension(FYL)
        print "    Reduction component:"
        print "        ", w.residue_field()
        print "        ", w
        print "         ground field: ", Lm
        print "    ------------"
︡ed37b9ce-65d8-43a1-877e-2109a0fbca1c︡{"done":true}︡
︠5e049e04-bd1e-4af6-a695-9777eb3dfc06s︠
V = [v1, v2]
print "Computing stable reduction Yb:"
for v in V:
    print "over ", v
    reduction_component(v, vL, f)
for i in range(len(filt)):
    m = filt[i][0]+1
    vLm = filt[i][2]
    print "Computing Y_m for m=%s:"%m
    for v in V:
        print "over ", v
        reduction_component(v, vLm, f)
︡b07d39cd-6f47-46ec-9860-cbb464e64ae6︡{"stdout":"Computing stable reduction Yb:\n"}︡{"stdout":"over  [ Gauss valuation induced by 2-adic valuation, v(x + 1) = 1/4, v(x^4 + 14*x^2 + 72*x - 41) = 3 ]\n    Reduction component:"}︡{"stdout":"\n         Function field in u2 defined by u2^3 + z^4 + z^2\n         Valuation on rational function field induced by [ Gauss valuation induced by Valuation on rational function field induced by [ Gauss valuation induced by pi-adic valuation, v(z + pi^9 + pi^6 + 1) = 18 ], v(y) = 24, v(y^3 - z^4 - 14*z^2 - 72*z + 41) = +Infinity ]\n         ground field:  Number Field in pi with defining polynomial x^24 + 20*x^21 + 8*x^18 + 72*x^15 + 70*x^12 + 48*x^9 + 76*x^6 + 16*x^3 + 82\n    ------------\nover  [ Gauss valuation induced by 2-adic valuation, v(x + 1) = 1/4, v(x^4 + 14*x^2 + 72*x - 41) = 7/2 ]\n    Reduction component:"}︡{"stdout":"\n         Function field in u2 defined by u2^3 + z^2 + z\n         Valuation on rational function field induced by [ Gauss valuation induced by Valuation on rational function field induced by [ Gauss valuation induced by pi-adic valuation, v(z + pi^21 + pi^18 + pi^9 + pi^6 + 1) = 24 ], v(y) = 28, v(y^3 - z^4 - 14*z^2 - 72*z + 41) = +Infinity ]\n         ground field:  Number Field in pi with defining polynomial x^24 + 20*x^21 + 8*x^18 + 72*x^15 + 70*x^12 + 48*x^9 + 76*x^6 + 16*x^3 + 82\n    ------------\n    Reduction component:"}︡{"stdout":"\n         Function field in u2 defined by u2^3 + z^2 + z\n         Valuation on rational function field induced by [ Gauss valuation induced by Valuation on rational function field induced by [ Gauss valuation induced by pi-adic valuation, v(z + pi^21 + pi^9 + pi^6 + 1) = 24 ], v(y) = 28, v(y^3 - z^4 - 14*z^2 - 72*z + 41) = +Infinity ]\n         ground field:  Number Field in pi with defining polynomial x^24 + 20*x^21 + 8*x^18 + 72*x^15 + 70*x^12 + 48*x^9 + 76*x^6 + 16*x^3 + 82\n    ------------\n"}︡{"stdout":"Computing Y_m for m=16:\nover  [ Gauss valuation induced by 2-adic valuation, v(x + 1) = 1/4, v(x^4 + 14*x^2 + 72*x - 41) = 3 ]\n    Reduction component:"}︡{"stdout":"\n         Function field in u2 defined by u2^3 + z^2 + z\n         Valuation on rational function field induced by [ Gauss valuation induced by Valuation on rational function field induced by [ Gauss valuation induced by pi12-adic valuation, v(z + pi12^3 + 1) = 9/2, v(z^2 + (-4*pi12^9 - 6*pi12^6 - 2*pi12^3)*z + 7*pi12^9 + 15*pi12^6 + 12*pi12^3 + 7) = 18 ], v(y) = 12, v(y^3 - z^4 - 14*z^2 - 72*z + 41) = +Infinity ]\n         ground field:  Number Field in pi12 with defining polynomial x^12 + 4*x^9 + 6*x^6 + 4*x^3 + 2\n    ------------\nover  [ Gauss valuation induced by 2-adic valuation, v(x + 1) = 1/4, v(x^4 + 14*x^2 + 72*x - 41) = 7/2 ]\n    Reduction component:"}︡{"stdout":"\n         Function field in u2 defined by u2^3 + z + 1\n         Valuation on rational function field induced by [ Gauss valuation induced by Valuation on rational function field induced by [ Gauss valuation induced by pi12-adic valuation, v(z + pi12^3 + 1) = 9/2, v(z^2 + (6*pi12^9 + 14*pi12^6 + 12*pi12^3 + 8)*z - 23*pi12^9 - 57*pi12^6 - 38*pi12^3 - 25) = 24 ], v(y) = 14, v(y^3 - z^4 - 14*z^2 - 72*z + 41) = +Infinity ]\n         ground field:  Number Field in pi12 with defining polynomial x^12 + 4*x^9 + 6*x^6 + 4*x^3 + 2\n    ------------\n    Reduction component:"}︡{"stdout":"\n         Function field in u2 defined by u2^3 + z\n         Valuation on rational function field induced by [ Gauss valuation induced by Valuation on rational function field induced by [ Gauss valuation induced by pi12-adic valuation, v(z + pi12^3 + 1) = 9/2, v(z^2 + (6*pi12^9 + 14*pi12^6 + 12*pi12^3 + 8)*z + 31*pi12^9 + 77*pi12^6 + 54*pi12^3 + 35) = 24 ], v(y) = 14, v(y^3 - z^4 - 14*z^2 - 72*z + 41) = +Infinity ]\n         ground field:  Number Field in pi12 with defining polynomial x^12 + 4*x^9 + 6*x^6 + 4*x^3 + 2\n    ------------\nComputing Y_m for m=10:\nover  [ Gauss valuation induced by 2-adic valuation, v(x + 1) = 1/4, v(x^4 + 14*x^2 + 72*x - 41) = 3 ]\n    Reduction component:"}︡{"stdout":"\n         Function field in u2 defined by u2^3 + z\n         Valuation on rational function field induced by [ Gauss valuation induced by Valuation on rational function field induced by [ Gauss valuation induced by pi6-adic valuation, v(z + 1) = 3/2, v(z^2 + (pi6^3 + 2)*z + 2*pi6^3 + 1) = 21/4, v(z^4 + 14*z^2 + 72*z - 41) = 18 ], v(y) = 6, v(y^3 - z^4 - 14*z^2 - 72*z + 41) = +Infinity ]\n         ground field:  Number Field in pi6 with defining polynomial x^6 + 2*x^3 + 2\n    ------------\nover  [ Gauss valuation induced by 2-adic valuation, v(x + 1) = 1/4, v(x^4 + 14*x^2 + 72*x - 41) = 7/2 ]\n    Reduction component:"}︡{"stdout":"\n         Function field in u2 defined by u2^3 + z\n         Valuation on rational function field induced by [ Gauss valuation induced by Valuation on rational function field induced by [ Gauss valuation induced by pi6-adic valuation, v(z + 1) = 3/2, v(z^2 + (pi6^3 + 2)*z + 2*pi6^3 + 1) = 21/4, v(z^4 + 14*z^2 + 72*z - 41) = 21 ], v(y) = 7, v(y^3 - z^4 - 14*z^2 - 72*z + 41) = +Infinity ]\n         ground field:  Number Field in pi6 with defining polynomial x^6 + 2*x^3 + 2\n    ------------\nComputing Y_m for m=4:\nover  [ Gauss valuation induced by 2-adic valuation, v(x + 1) = 1/4, v(x^4 + 14*x^2 + 72*x - 41) = 3 ]\n    Reduction component:"}︡{"stdout":"\n         Function field in u2 defined by u2^3 + z\n         Valuation on rational function field induced by [ Gauss valuation induced by Valuation on rational function field induced by [ Gauss valuation induced by pi3-adic valuation, v(z + 1) = 3/4, v(z^4 + 14*z^2 + 72*z - 41) = 9 ], v(y) = 3, v(y^3 - z^4 - 14*z^2 - 72*z + 41) = +Infinity ]\n         ground field:  Number Field in pi3 with defining polynomial x^3 + 2\n    ------------\nover  [ Gauss valuation induced by 2-adic valuation, v(x + 1) = 1/4, v(x^4 + 14*x^2 + 72*x - 41) = 7/2 ]\n    Reduction component:"}︡{"stdout":"\n         Function field in u2 defined by u2^3 + z\n         Valuation on rational function field induced by [ Gauss valuation induced by Valuation on rational function field induced by [ Gauss valuation induced by pi3-adic valuation, v(z + 1) = 3/4, v(z^4 + 14*z^2 + 72*z - 41) = 21/2 ], v(y) = 7/2, v(y^3 - z^4 - 14*z^2 - 72*z + 41) = +Infinity ]\n         ground field:  Number Field in pi3 with defining polynomial x^3 + 2\n    ------------\nComputing Y_m for m=1:\nover  [ Gauss valuation induced by 2-adic valuation, v(x + 1) = 1/4, v(x^4 + 14*x^2 + 72*x - 41) = 3 ]\n    Reduction component:"}︡{"stdout":"\n         Function field in u2 defined by u2^3 + z\n         Valuation on rational function field induced by [ Gauss valuation induced by Valuation on rational function field induced by [ Gauss valuation induced by 2-adic valuation, v(z + 1) = 1/4, v(z^4 + 14*z^2 + 72*z - 41) = 3 ], v(y) = 1, v(y^3 - z^4 - 14*z^2 - 72*z + 41) = +Infinity ]\n         ground field:  Rational Field\n    ------------\nover  [ Gauss valuation induced by 2-adic valuation, v(x + 1) = 1/4, v(x^4 + 14*x^2 + 72*x - 41) = 7/2 ]\n    Reduction component:"}︡{"stdout":"\n         Rational function field in z over Finite Field of size 2\n         Valuation on rational function field induced by [ Gauss valuation induced by Valuation on rational function field induced by [ Gauss valuation induced by 2-adic valuation, v(z + 1) = 1/4, v(z^4 + 14*z^2 + 72*z - 41) = 7/2 ], v(y) = 7/6, v(y^3 - z^4 - 14*z^2 - 72*z + 41) = +Infinity ]\n         ground field:  Rational Field\n    ------------\n"}︡{"done":true}︡
︠6a5b8c91-1407-407b-883f-24de6a8393e4i︠
%md
We see that $g(\bar{Y}_m)=0$ for $m=0,\ldots,9$, $=1$ for $m=10,\ldots,15$ and $=3$ for $m\geq 16$. It follows that
$$
    f_2 = \sum_{m=0}^\infty \frac{|\Gamma_m|}{|\Gamma_0|}(2g_y-2g_{\bar{Y}_m}) = 6(1+3\cdot\frac{1}{3}+5\cdot\frac{1}{6})+4(6\cdot\frac{1}{12}) = 19.
$$
︡dcc6bc87-d22b-45b6-95fa-f191081b83ea︡{"done":true,"md":"We see that $g(\\bar{Y}_m)=0$ for $m=0,\\ldots,9$, $=1$ for $m=10,\\ldots,15$ and $=3$ for $m\\geq 16$. It follows that\n$$\n    f_2 = \\sum_{m=0}^\\infty \\frac{|\\Gamma_m|}{|\\Gamma_0|}(2g_y-2g_{\\bar{Y}_m}) = 6(1+3\\cdot\\frac{1}{3}+5\\cdot\\frac{1}{6})+4(6\\cdot\\frac{1}{12}) = 19.\n$$"}
︠5ef3a6c3-10aa-40b1-b887-9bab4d55da95i︠
︡4f0ce694-0d7d-4db8-962c-ca7ca823920b︡
︠978b3879-d0c0-4db0-b05c-a9db9513602ei︠
%md
Now we have to compute $f_3$.
︡e1803028-acf3-43a2-93f8-00aadb554e36︡{"done":true,"md":"Now we have to compute $f_3$."}
︠f20340ee-3a30-490c-8206-106bfdd43c27s︠
p=3
v_K = pAdicValuation(K,p)
load("../../semistable_reduction/superp.sage")
︡04f6b080-d718-40ca-8d37-4e551fe779a5︡{"done":true}︡
︠c1a2b0ad-7a2b-433f-b026-1097ab361c34s︠
Y = Superp(f, v_K, p)
Y.FY
︡c1a4baf7-580d-47fb-9ab3-c328fa212519︡{"stdout":"Function field in y defined by y^3 - x^4 + 3*x^3 + 24*x^2 + x\n"}︡{"done":true}︡
︠45e1659f-e9d2-42e2-953a-76ac1e985aces︠
Y.compute_semistable_reduction()
︡05f823ef-504d-4b31-9466-e652497a960e︡{"stdout":"L0 = "}︡{"stdout":" Rational Field\nL1 = "}︡{"stdout":" Number Field in pi2 with defining polynomial x^2 + 3\nInertial reduction component:"}︡{"stdout":"\n     Function field in u2 defined by x*u2^3 + u2 + 2\n     [ Gauss valuation induced by 3-adic valuation, v(x + 2) = 1, v(x + 8) = 5/4 ]\n--------------\nReduction component:"}︡{"stdout":"\n     Function field in u2 defined by u2^3 + 2*u2 + 2*z^2\n     constant field:  Finite Field of size 3\n     [ Gauss valuation induced by 3-adic valuation, v(x + 2) = 1, v(x + 8) = 5/4 ]\n     splitting field:  Number Field in pi4 with defining polynomial x^4 + 3\n------------\nL0 =  Rational Field\nL1 = "}︡{"stdout":" Number Field in pi3 with defining polynomial x^3 + 2181*x^2 + 12*x + 2181\nInertial reduction component:"}︡{"stdout":"\n     Rational function field in x over Finite Field of size 3\n     [ Gauss valuation induced by 3-adic valuation, v(x + 2) = 1 ]\n--------------\nReduction component:"}︡{"stdout":"\n     Function field in u2 defined by u2^3 + 2*z^4 + 2*z^3 + 2*z^2\n     constant field:  Finite Field of size 3\n     [ Gauss valuation induced by 3-adic valuation, v(x + 2) = 1 ]\n     splitting field:  Number Field in pi3 with defining polynomial x^3 + 2181*x^2 + 12*x + 2181\n------------\nL0 =  Rational Field\nL1 = "}︡{"stdout":" Number Field in pi3 with defining polynomial x^3 + 2181*x^2 + 12*x + 2181\nInertial reduction component:"}︡{"stdout":"\n     Rational function field in x over Finite Field of size 3\n     [ Gauss valuation induced by 3-adic valuation, v(x + 2) = 5/4 ]\n--------------\nReduction component:"}︡{"stdout":"\n     Function field in u2 defined by u2^3 + 2*u2 + 2*z^2\n     constant field:  Finite Field of size 3\n     [ Gauss valuation induced by 3-adic valuation, v(x + 2) = 5/4 ]\n     splitting field:  Number Field in pi12 with defining polynomial x^12 + 2181*x^8 + 12*x^4 + 2181\n------------\nL0 = "}︡{"stdout":" Number Field in pi6 with defining polynomial x^6 + 2184\nL1 = "}︡{"stdout":" Number Field in pi6 with defining polynomial x^6 + 2184\nInertial reduction component:"}︡{"stdout":"\n     Function field in u2 defined by 2*x^2*u2^3 + 2\n     [ Gauss valuation induced by 3-adic valuation, v(x + 2) = 1, v(x + 5) = 5/3, v(x^3 + 15*x^2 + 75*x + 368) = 21/4 ]\n--------------\nReduction component:"}︡{"stdout":"\n     Function field in u2 defined by u2^3 + u2 + 2*z^2\n     constant field:  Finite Field of size 3\n     [ Gauss valuation induced by 3-adic valuation, v(x + 2) = 1, v(x + 5) = 5/3, v(x^3 + 15*x^2 + 75*x + 368) = 21/4 ]\n     splitting field:  Number Field in pi12 with defining polynomial x^12 + 2184\n------------\n"}︡{"done":true}︡
︠6b8c3e86-3849-4be3-b3ad-1d4e43042e21i︠
%md
We see that the stable reduction of $Y$ is of type (c), i.e. with three tail components of genus one. One of these components has a splitting field which is a totally ramified Galois extension of $\mathbb{Q}_3$ of degree $12$. The two other components form an orbit under the Galois group of $\mathbb{F}_9/\mathbb{F}_3$. A splitting field is a Galois extension of degree $24$ of $\mathbb{Q}_3$ with ramification index $12$. 

Now we compute the quotients $W_m=W/\Gamma_m$ of these three components.
︡fb3536ba-6678-4b6f-b682-e11ce2f16db4︡{"done":true,"md":"We see that the stable reduction of $Y$ is of type (c), i.e. with three tail components of genus one. One of these components has a splitting field which is a totally ramified Galois extension of $\\mathbb{Q}_3$ of degree $12$. The two other components form an orbit under the Galois group of $\\mathbb{F}_9/\\mathbb{F}_3$. A splitting field is a Galois extension of degree $24$ of $\\mathbb{Q}_3$ with ramification index $12$. \n\nNow we compute the quotients $W_m=W/\\Gamma_m$ of these three components."}
︠d1936df7-9724-408a-be8f-79eef4e19ba9s︠
for c in Y.components:
    c.compute_ramification_filtration_reduction()
    

︡2688a564-e29b-4178-9235-61e24bfe0f57︡{"stdout":"components over  [ Gauss valuation induced by 3-adic valuation, v(x + 2) = 1, v(x + 8) = 5/4 ]\nthe splitting field is  Number Field in pi4 with defining polynomial x^4 + 3\n[(0, 4, 3-adic valuation)]\nThe ramification breaks are: [1]\nComputing Y_m for m=0 and |Gm|=4:\nintermediate field:  Rational Field  with ramification index  1\n    Reduction component:"}︡{"stdout":"\n         Function field in u2 defined by z*u2^3 + u2 + 2\n         Valuation on rational function field induced by [ Gauss valuation induced by Valuation on rational function field induced by [ Gauss valuation induced by 3-adic valuation, v(z + 8) = 5/4 ], v(y + 2*z + 19) = 3/2, v(y^3 - z^4 + 3*z^3 + 24*z^2 + z) = +Infinity ]\ncomponents over  [ Gauss valuation induced by 3-adic valuation, v(x + 2) = 1 ]\nthe splitting field is  Number Field in pi3 with defining polynomial x^3 + 2181*x^2 + 12*x + 2181\n[(1/2, 3, 3-adic valuation)]\nThe ramification breaks are: [3/2]\nComputing Y_m for m=1/2 and |Gm|=3:\nintermediate field:  Rational Field  with ramification index  1\n    Reduction component:"}︡{"stdout":"\n         Rational function field in z over Finite Field of size 3\n         Valuation on rational function field induced by [ Gauss valuation induced by Valuation on rational function field induced by [ Gauss valuation induced by 3-adic valuation, v(z + 2) = 1 ], v(y + 2*z + 10) = 4/3, v(y^3 - z^4 + 3*z^3 + 24*z^2 + z) = +Infinity ]\ncomponents over  [ Gauss valuation induced by 3-adic valuation, v(x + 2) = 5/4 ]\nthe splitting field is  Number Field in pi12 with defining polynomial x^12 + 2181*x^8 + 12*x^4 + 2181\n[(2, 3, pi4-adic valuation), (0, 12, 3-adic valuation)]"}︡︡{"stdout":"\nThe ramification breaks are: [3, 1]\nComputing Y_m for m=2 and |Gm|=3:\nintermediate field:  Number Field in pi4 with defining polynomial x^4 + 3  with ramification index  4\n    Reduction component:"}︡{"stdout":"\n         Rational function field in z over Finite Field of size 3\n         Valuation on rational function field induced by [ Gauss valuation induced by Valuation on rational function field induced by [ Gauss valuation induced by pi4-adic valuation, v(z + 2) = 5 ], v(y + 2*z + 1) = 16/3, v(y^3 - z^4 + 3*z^3 + 24*z^2 + z) = +Infinity ]\nComputing Y_m for m=0 and |Gm|=12:\nintermediate field:  Rational Field  with ramification index  1\n    Reduction component:"}︡{"stdout":"\n         Rational function field in z over Finite Field of size 3\n         Valuation on rational function field induced by [ Gauss valuation induced by Valuation on rational function field induced by [ Gauss valuation induced by 3-adic valuation, v(z + 2) = 5/4 ], v(y + 2*z + 10) = 4/3, v(y^3 - z^4 + 3*z^3 + 24*z^2 + z) = +Infinity ]\ncomponents over  [ Gauss valuation induced by 3-adic valuation, v(x + 2) = 1, v(x + 5) = 5/3, v(x^3 + 15*x^2 + 75*x + 368) = 21/4 ]\nthe splitting field is  Number Field in pi12 with defining polynomial x^12 + 2184\n[(6, 3, pi4-adic valuation), (0, 12, 3-adic valuation)]"}︡{"stdout":"\nThe ramification breaks are: [7, 1]\nComputing Y_m for m=6 and |Gm|=3:\nintermediate field:  Number Field in pi4 with defining polynomial x^4 + 1419  with ramification index  4\n    Reduction component:"}︡{"stdout":"\n         Function field in u2 defined by 2*u2^3 + 2*z\n         Valuation on rational function field induced by [ Gauss valuation induced by Valuation on rational function field induced by [ Gauss valuation induced by pi4-adic valuation, v(z - 1417) = 20/3, v(z^3 + 15*z^2 + 75*z + 368) = 21 ], v(y + 1/2013561*z^2 - 2834/2013561*z + 2007889/2013561) = 17/3, v(y^3 - z^4 + 3*z^3 + 24*z^2 + z) = +Infinity ]\nComputing Y_m for m=0 and |Gm|=12:\nintermediate field:  Rational Field  with ramification index  1\n    Reduction component:"}︡{"stdout":"\n         Function field in u2 defined by 2*z^2*u2^3 + 2\n         Valuation on rational function field induced by [ Gauss valuation induced by Valuation on rational function field induced by [ Gauss valuation induced by 3-adic valuation, v(z + 5) = 5/3, v(z^3 + 15*z^2 + 75*z + 368) = 21/4 ], v(y + 1/9*z^2 + 10/9*z + 25/9) = 17/12, v(y^3 - z^4 + 3*z^3 + 24*z^2 + z) = +Infinity ]\n"}︡{"done":true}
︠a5466ad6-5600-4a20-a238-d641aa7cd488i︠
%md
The splitting field of the first component has ramification breaks $1,3$, with $|\Gamma_0|=12$ and $|\Gamma_1|=3$. We have $g(W_3)=0$, hence the contribution to the conductor is
$$
    2(1+2\cdot\frac{1}{4}) = 3.
$$ 
The splitting field of the each of the other two components has ramification breaks $1,7$, with $|\Gamma_0|=12$ and $|\Gamma_6|=3$. So the contribution of one of these components is
$$
    2(1+6\cdot \frac{1}{4}) = 5.
$$
So the conductor exponents at $p=3$ is
$$
     f_3 = 3 + 2\cdot 5 = 13.
$$

All in all, the conductor of $Y$ is 
$$
     N_Y = 2^{19}3^{13} = 835884417024.
$$
︡0958ffb4-e136-49ae-99b1-ace7a5baeb6f︡{"done":true,"md":"The splitting field of the first component has ramification breaks $1,3$, with $|\\Gamma_0|=12$ and $|\\Gamma_1|=3$. We have $g(W_3)=0$, hence the contribution to the conductor is\n$$\n    2(1+2\\cdot\\frac{1}{4}) = 3.\n$$ \nThe splitting field of the each of the other two components has ramification breaks $1,7$, with $|\\Gamma_0|=12$ and $|\\Gamma_6|=3$. So the contribution of one of these components is\n$$\n    2(1+6\\cdot \\frac{1}{4}) = 5.\n$$\nSo the conductor exponents at $p=3$ is\n$$\n     f_3 = 3 + 2\\cdot 5 = 13.\n$$\n\nAll in all, the conductor of $Y$ is \n$$\n     N_Y = 2^{19}3^{13} = 835884417024.\n$$"}
︠36582191-241c-469c-9426-6831c91713c9s︠
2^19*3^13
︡667c0516-1258-4c59-b502-5746fbba6563︡{"stdout":"835884417024\n"}︡{"done":true}︡
︠a81d80a6-341b-4b25-b3bf-a1da56b29356i︠
%md
### 2. Example ###

A similar example is the curve 
\[
    Y:\; y^3 = x^4 - 24x^2 - 76x +24.
\]
Here $\Delta(f) = 2^83^55^6$.
︡577115ab-0199-4252-9630-0224a2374cd9︡{"done":true,"md":"### 2. Example ###\n\nA similar example is the curve \n\\[\n    Y:\\; y^3 = x^4 - 24x^2 - 76x +24.\n\\]\nHere $\\Delta(f) = 2^83^55^6$."}
︠e4877366-e0a6-4232-999b-7e858c1bcb30s︠
f = x^4-24*x^2-76*x+24
f.discriminant().factor()
︡6b00830f-35d3-4802-9aed-cc4945d62a80︡{"stdout":"-1 * 2^8 * 3^5 * 5^6\n"}︡{"done":true}︡
︠91f534f4-261b-43e2-a2a0-ecf221069415i︠
%md 
Let us first see what happens for $p=2$.
︡df91c835-bacb-481a-a2ae-d6c3e8adf44d︡{"done":true,"md":"Let us first see what happens for $p=2$."}
︠cd719ee9-f323-4e9d-b774-8806b7fe6f85s︠
f.change_ring(GF(2)).factor()
p = 2
vK = pAdicValuation(K, 2)
V = vK.mac_lane_approximants(f)
V[0].mac_lane_step(f)
V[1].mac_lane_step(f)
︡26bc64a4-9add-412c-82af-23de923b341a︡{"stdout":"x^4\n"}︡{"stdout":"[[ Gauss valuation induced by 2-adic valuation, v(x + 2) = 3 ]]\n"}︡{"stdout":"[[ Gauss valuation induced by 2-adic valuation, v(x) = 2/3, v(x^3 + 4) = 7/3 ]]\n"}︡{"done":true}︡
︠c0060d16-4642-4444-9734-5ed35afb69d0s︠
L0.<alpha> = f.splitting_field()
L0
vL0 = vK.extension(L0)
vL0.residue_field()
vL0(2)
fL0 = f.change_ring(L0)
a = fL0.roots(multiplicities=None)
[vL0(a[0]-a[i]) for i in range(4)]
︡8089635e-2b2b-49de-9989-092129143fb3︡{"stdout":"Number Field in alpha with defining polynomial x^6 + 15*x^5 + 96*x^4 + 311*x^3 + 492*x^2 + 339*x + 247\n"}︡{"stdout":"Finite Field in u1 of size 2^2\n"}︡{"stdout":"3\n"}︡{"stdout":"[+Infinity, 2, 2, 2]\n"}︡{"done":true}︡
︠f15557c1-2a99-4390-a77f-9493035a9071s︠
vL = padic_sufficiently_ramified_extension(vL0, 9)
vL
v0 = GaussValuation(R, vK)
v1 = v0.extension(x, 2/3)
reduction_component(v1, vL, f)
︡50a44912-7fbb-4b0d-8ebe-365a0bdd24be︡{"stdout":"pi18-adic valuation\n"}︡{"stdout":"    Reduction component:"}︡{"stdout":"\n         Function field in u2 defined by u2^3 + z^4 + z\n         Valuation on rational function field induced by [ Gauss valuation induced by Valuation on rational function field induced by [ Gauss valuation induced by pi18-adic valuation, v(z) = 6 ], v(y) = 8, v(y^3 - z^4 + 24*z^2 + 76*z - 24) = +Infinity ]\n         ground field:  Number Field in pi18 with defining polynomial x^18 + 20*x^15 + 28*x^12 + 76*x^9 + 104*x^6 + 112*x^3 + 68\n    ------------\n"}︡{"done":true}︡
︠156d0dc6-2e75-436e-ab49-74a13028f5f0i︠
%md 
We see that $Y$ has potentially good reduction over a tamely ramified extension of $\mathbb{Q}_2$ (of degree $18$). However, $\bar{Y}_0=\bar{Y}/\Gamma_0$ has genus $0$. It follows that 
$$
  f_2 = 6.
$$
︡951e09ef-e323-402b-8d4d-5d95b5bec735︡{"done":true,"md":"We see that $Y$ has potentially good reduction over a tamely ramified extension of $\\mathbb{Q}_2$ (of degree $18$). However, $\\bar{Y}_0=\\bar{Y}/\\Gamma_0$ has genus $0$. It follows that \n$$\n  f_2 = 6.\n$$"}
︠ac373af1-b320-405a-b760-3b7f9d4a6be2i︠
%md 
Now we look at $p=3$.
︡edea7854-1f4d-4569-9015-1f8e2d0bb5b7︡{"done":true,"md":"Now we look at $p=3$."}
︠9fe61d28-48c4-40fd-af06-7eeae4f9fc7cs︠
p=3
v_K = pAdicValuation(K,p)
load("../../semistable_reduction/superp.sage")
Y = Superp(f, v_K, p)
Y.FY
︡48e1e53f-bf89-4421-b67f-06fef436c6aa︡{"stdout":"Function field in y defined by y^3 - x^4 + 24*x^2 + 76*x - 24\n"}︡{"done":true}︡
︠d2caf384-7881-47d9-871e-9b9e709476cas︠
Y.compute_semistable_reduction()
︡e9e7fa38-5988-49ff-b2a0-365a254f1256︡{"stdout":"Inertial reduction component:"}︡{"stdout":"\n     Function field in u2 defined by x^2*u2^3 + 1\n     [ Gauss valuation induced by 3-adic valuation, v(x + 2) = 1/3, v(x^3 + 6*x^2 + 12*x + 14) = 5/3, v(x^3 + 9*x^2 + 24*x + 26) = 2, v(x^3 + 9*x^2 + 24*x + 44) = 19/9, v(x^9 + 27*x^8 + 315*x^7 + 2157*x^6 + 9936*x^5 + 32580*x^4 + 76656*x^3 + 128304*x^2 + 140850*x + 88100) = 20/3, v(x^9 + 27*x^8 + 315*x^7 + 2157*x^6 + 9936*x^5 + 32580*x^4 + 76656*x^3 + 129033*x^2 + 143766*x + 91016) = 27/4 ]\n--------------\n"}︡{"done":true}︡
︠491d71fe-b9df-460d-b652-da4b5c20bd41i︠
%md 
Unfortunately, the computation of the splitting field leads to an error...
︡e5e8c874-7d7c-4adc-9449-fa86f3391b4f︡{"done":true,"md":"Unfortunately, the computation of the splitting field leads to an error..."}
︠5a22c7e4-a504-4c1d-828c-368a92521740i︠
%md
### Example 3: ###

One more example:
$$
    Y:\; y^3 = f(x) = x^4-3x^3-24x^2-x.
$$
We have $\Delta(f) = 3^{10}$, so we only have to look at $p=3$.
︡613549de-8776-4156-acba-73a116ab6f99︡{"done":true,"md":"### Example 3: ###\n\nOne more example:\n$$\n    Y:\\; y^3 = f(x) = x^4-3x^3-24x^2-x.\n$$\nWe have $\\Delta(f) = 3^{10}$, so we only have to look at $p=3$."}
︠40aefecc-d6c7-4682-bbb6-f5e311146f35s︠
f = x^4-3*x^3-24*x^2-x
f.discriminant().factor()
︡969c11d2-c109-4af4-8073-6b4d0186a819︡{"stdout":"3^10\n"}︡{"done":true}︡
︠fa2a2c2a-39a1-4416-9097-9f3303ef045as︠
load("../../semistable_reduction/superp.sage")
Y = Superp(f, v_K, p)
Y.FY
Y.compute_semistable_reduction()
︡3cb12565-2045-4534-a9b1-a933818f465b︡{"stdout":"Function field in y defined by y^3 - x^4 + 3*x^3 + 24*x^2 + x\n"}︡{"stdout":"Inertial reduction component:"}︡{"stdout":"\n     Function field in u2 defined by x*u2^3 + u2 + 2\n     [ Gauss valuation induced by 3-adic valuation, v(x + 2) = 1, v(x + 8) = 5/4 ]\n--------------\nInertial reduction component:"}︡{"stdout":"\n     Rational function field in x over Finite Field of size 3\n     [ Gauss valuation induced by 3-adic valuation, v(x + 2) = 1 ]\n--------------\nInertial reduction component:"}︡{"stdout":"\n     Rational function field in x over Finite Field of size 3\n     [ Gauss valuation induced by 3-adic valuation, v(x + 2) = 5/4 ]\n--------------\nInertial reduction component:"}︡{"stdout":"\n     Function field in u2 defined by 2*x^2*u2^3 + 2\n     [ Gauss valuation induced by 3-adic valuation, v(x + 2) = 1, v(x + 5) = 5/3, v(x^3 + 15*x^2 + 75*x + 368) = 21/4 ]\n--------------\n"}︡{"done":true}︡
︠161ff15b-ab21-4c07-a908-e5eada86038ci︠
%md
We see that the stable reduction $\bar{Y}$ of $Y$ consists of $4$ components, three of genus $1$ and one of genus $0$ (*type (c)*).

The first component $W_1$ of genus $1$ has a tamely ramified splitting field and its inertial reduction has genus $0$. So $g(W_0)=0$ and $g(W_m)=1$ for $m\geq 1$. The contribution of $W_1$ to the conductor exponent is therefore $2$.
︡8bafd9dd-7928-4e26-a509-2f0761200af8︡{"done":true,"md":"We see that the stable reduction $\\bar{Y}$ of $Y$ consists of $4$ components, three of genus $1$ and one of genus $0$ (*type (c)*).\n\nThe first component $W_1$ of genus $1$ has a tamely ramified splitting field and its inertial reduction has genus $0$. So $g(W_0)=0$ and $g(W_m)=1$ for $m\\geq 1$. The contribution of $W_1$ to the conductor exponent is therefore $2$."}
︠4874d0bc-1cd8-47d3-b90e-adfa8a8093bci︠
%md
To compute the contribution of the second component $W_2$ fo genus $1$, we analyse the ramificaton filtration of its splitting field. 
︡273cec59-a525-47b4-8d5d-b3afb7853c89︡{"done":true,"md":"To compute the contribution of the second component $W_2$ fo genus $1$, we analyse the ramificaton filtration of its splitting field."}
︠ef50684d-c062-4adc-868a-32745a9120d2︠

︡38ac7437-2f69-42f6-ba04-2463c8f5d24b︡︠5b4a915d-68f7-4fa4-b766-fcc4f2580f8c︠
︠f01f02b5-0b5c-4fa7-b987-9c43995a7f09︠
︡f8e5520c-298c-40c4-916d-fa7f32b9cc42︡
︠7497a2a2-ddbf-463a-b41a-90f134ada622︠
︡399eeb1d-1eee-4eaa-b2d8-b30d5d175f4a︡
︠7ec9613e-6565-48cc-ae27-b8c004e1e7bc︠

︡81ec16be-ca88-4153-bac0-f0b775723bc0︡
︠fc804707-8f10-4899-a9cc-61335ae6b665s︠
c = Y.components[2]
v = c.v
vL, w = c.reduction[0]
vL.domain()
w.residue_field()
︡fb48cfef-8c74-4ee5-bc3b-8720444e0cf0︡{"stderr":"Error in lines 1-1\nTraceback (most recent call last):\n  File \"/usr/local/lib/python2.7/dist-packages/smc_sagews/sage_server.py\", line 995, in execute\n    exec compile(block+'\\n', '', 'single') in namespace, locals\n  File \"\", line 1, in <module>\nIndexError: list index out of range\n"}︡{"done":true}︡
︠65d55bf1-95a9-4941-87bd-cd1b45daa296s︠
filt = padic_ramification_filtration(vL, compute_subfields=True)
filt
︡4dd66b7d-d622-4b8d-a107-119329417b19︡{"stdout":"[(2, 3, pi4-adic valuation), (0, 12, 3-adic valuation)]\n"}︡{"done":true}︡
︠7dfaf30d-818c-47b7-afed-fdecf17239dfs︠
vK2 = filt[0][2]
vK2.domain()
reduction_component(v, vK2, f)
︡f6939448-a929-4f6d-9041-0a8e54c9d704︡{"stdout":"Number Field in pi4 with defining polynomial x^4 + 3\n"}︡{"stdout":"    Reduction component:"}︡{"stdout":"\n         Rational function field in z over Finite Field of size 3\n         Valuation on rational function field induced by [ Gauss valuation induced by Valuation on rational function field induced by [ Gauss valuation induced by pi4-adic valuation, v(z + 2) = 5 ], v(y + 2*z + 1) = 16/3, v(y^3 - z^4 + 3*z^3 + 24*z^2 + z) = +Infinity ]\n         ground field:  Number Field in pi4 with defining polynomial x^4 + 3\n    ------------\n"}︡{"done":true}︡
︠afc68d93-8e05-411e-83ba-af83a9482a82i︠
%md
We see that $|\Gamma_0|=12$, $|\Gamma_m|=3$ for $m=1,2$ and $\Gamma_m=1$ for $m\geq 3$. Also,
$g(W_2/\Gamma_2)=0$ and $g(W_2/\Gamma_3)=1$. It follows that the contribution is 
$$
    2(1 + 2\frac{1}{4}) = 3.
$$    
︡ccaa80be-e862-4080-92ab-05645340ee7e︡{"done":true,"md":"We see that $|\\Gamma_0|=12$, $|\\Gamma_m|=3$ for $m=1,2$ and $\\Gamma_m=1$ for $m\\geq 3$. Also,\n$g(W_2/\\Gamma_2)=0$ and $g(W_2/\\Gamma_3)=1$. It follows that the contribution is \n$$\n    2(1 + 2\\frac{1}{4}) = 3.\n$$"}
︠76f28c5e-705f-4016-a283-5fb4c6ee6075s︠
c = Y.components[3]
v = c.v
vL, w = c.reduction[0]
vL.domain()
w.residue_field()
filt = padic_ramification_filtration(vL, compute_subfields=True)
filt
︡7327f59c-7c69-4f00-86eb-b41a3dd4a5d6︡{"stdout":"Number Field in pi12 with defining polynomial x^12 + 2184\n"}︡{"stdout":"Function field in u2 defined by u2^3 + u2 + 2*z^2\n"}︡{"stdout":"[(6, 3, pi4-adic valuation), (0, 12, 3-adic valuation)]\n"}︡{"done":true}︡
︠7e95aa44-0f7e-4898-bfc0-290f625ccee6s︠
vK2 = filt[0][2]
vK2.domain()
reduction_component(v, vK2, f)
︡a47ff7ab-fdf2-4fae-b3e6-8834602a8fc5︡{"stdout":"Number Field in pi4 with defining polynomial x^4 + 1419\n"}︡︡{"stdout":"    Reduction component:"}︡{"stdout":"\n         Function field in u2 defined by 2*u2^3 + 2*z\n         Valuation on rational function field induced by [ Gauss valuation induced by Valuation on rational function field induced by [ Gauss valuation induced by pi4-adic valuation, v(z - 1417) = 20/3, v(z^3 + 15*z^2 + 75*z + 368) = 21 ], v(y + 1/2013561*z^2 - 2834/2013561*z + 2007889/2013561) = 17/3, v(y^3 - z^4 + 3*z^3 + 24*z^2 + z) = +Infinity ]\n         ground field:  Number Field in pi4 with defining polynomial x^4 + 1419\n    ------------\n"}︡{"done":true}
︠6a479186-8199-4613-8581-5105cc0ac8f7i︠
% md
For the splitting field of the last component $W_3$ we have $|\Gamma_0|=12$, $|\Gamma_m|=3$ for $m=1,\ldots,6$ and $\Gamma_m=1$ for $m\geq 7$.
Also, $g(W_3/\Gamma_m)=0$ for $m=0,\ldots,6$. Hence the contribution of $W_3$ is
$$
    2(1 + 6\cdot\frac{1}{4}) = 5.
$$    
Altogether, we see that the conductor exponent is
$$
   f_3 = 2 + 3 + 5 = 10.
$$    
︡1a8bddeb-e820-43ee-b5db-0dc65146976c︡{"done":true,"md":"For the splitting field of the last component $W_3$ we have $|\\Gamma_0|=12$, $|\\Gamma_m|=3$ for $m=1,\\ldots,6$ and $\\Gamma_m=1$ for $m\\geq 7$.\nAlso, $g(W_3/\\Gamma_m)=0$ for $m=0,\\ldots,6$. Hence the contribution of $W_3$ is\n$$\n    2(1 + 6\\cdot\\frac{1}{4}) = 5.\n$$    \nAltogether, we see that the conductor exponent is\n$$\n   f_3 = 2 + 3 + 5 = 10.\n$$"}
︠379b27ae-0cba-4169-9635-53b6b38f55b2︠









